@@ -32,7 +32,7 @@
 
 #include "prefs.h"
 
-gchar *homepage_string=(gchar*)"http://sciteproj.gusnan.se";
+gchar *homepage_string=(gchar*)"http://www.gusnan.se/sciteproj";
 
 gchar *sVersion = (gchar*)SCITEPROJ_VERSION;
 
@@ -147,7 +147,7 @@ void create_about_dialog()
 #endif
 
 	// Show SciteProj copyrights
-	copyrightstring=g_strdup_printf("Copyright (C) 2008-2012 Andreas Rönnquist <gusnan@gusnan.se>");
+	copyrightstring=g_strdup_printf("Copyright (C) 2008-2014 Andreas Rönnquist <gusnan@gusnan.se>");
 
 	copyright_label=gtk_label_new(copyrightstring);
 	gtk_label_set_selectable(GTK_LABEL(copyright_label),FALSE);
