@@ -4,7 +4,7 @@
  *  Copyright 2009-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj.
- * 
+ *
  * SciteProj is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -29,13 +29,10 @@
 
 #include "../graphics/dir-close.xpm"
 #include "../graphics/dir-open.xpm"
-#include "../graphics/text-x-cpp.xpm"
-#include "../graphics/text-x-h.xpm"
-#include "../graphics/text-x-txt.xpm"
-#include "../graphics/text-x-java.xpm"
-#include "../graphics/text-x-lua.xpm"
 #include "../graphics/sciteproj.xpm"
 
+#include "prefs.h"
+
 
 
 GdkPixbuf *header_file_pixbuf=NULL;
@@ -60,39 +57,39 @@ GdkCursor *busy_cursor=NULL;
  *	Loads all graphics required by the program
  * @return TRUE on success, FALSE on failure
  * @param err returns any errors
+ * @param widget - we need a widget for the gtk_widget_render_icon function
+ * 
  */
-gboolean load_graphics(GError **err)
+gboolean load_graphics(GtkWidget *widget, GError **err)
 {
-	GdkPixbuf *temp=NULL;
-	
+#if GTK_MAJOR_VERSION>=3
+	GtkIconTheme *icon_theme;
+
+	icon_theme = gtk_icon_theme_get_default();
+#endif
+
 	program_icon_pixbuf=gdk_pixbuf_new_from_xpm_data((const char **)sciteproj_xpm);
-	
-	directory_closed_pixbuf=gdk_pixbuf_new_from_xpm_data((const char**)dir_close_xpm);
-	directory_open_pixbuf=gdk_pixbuf_new_from_xpm_data((const char **)dir_open_xpm);
-	
-	temp=gdk_pixbuf_new_from_xpm_data((const char **)text_x_cpp_xpm);
-	cpp_file_pixbuf=gdk_pixbuf_scale_simple(temp,16,16,GDK_INTERP_HYPER);
-	g_object_unref(temp);
-	
-	temp=gdk_pixbuf_new_from_xpm_data((const char **)text_x_h_xpm);
-	header_file_pixbuf=gdk_pixbuf_scale_simple(temp,16,16,GDK_INTERP_HYPER);
-	g_object_unref(temp);
-	
-	temp=gdk_pixbuf_new_from_xpm_data((const char **)text_x_txt_xpm);
-	txt_file_pixbuf=gdk_pixbuf_scale_simple(temp,16,16,GDK_INTERP_HYPER);
-	g_object_unref(temp);
-	
-	temp=gdk_pixbuf_new_from_xpm_data((const char **)text_x_java_xpm);
-	java_file_pixbuf=gdk_pixbuf_scale_simple(temp,16,16,GDK_INTERP_HYPER);
-	g_object_unref(temp);
-	
-	temp=gdk_pixbuf_new_from_xpm_data((const char **)text_x_lua_xpm);
-	lua_file_pixbuf=gdk_pixbuf_scale_simple(temp,16,16,GDK_INTERP_HYPER);
-	g_object_unref(temp);
-	
+
+	if (prefs.use_stock_folder_icon) {
+
+		// use GTK_STOCK_DIRECTORY
+#if GTK_MAJOR_VERSION>=3
+		directory_closed_pixbuf = gtk_icon_theme_load_icon(icon_theme, "folder", 14, 0, NULL);
+		directory_open_pixbuf = gtk_icon_theme_load_icon(icon_theme, "folder", 14, 0, NULL);
+#else
+		directory_closed_pixbuf = gtk_widget_render_icon(widget, GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU, NULL);
+		directory_open_pixbuf = gtk_widget_render_icon(widget, GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU, NULL);
+#endif
+		
+	} else {
+		directory_open_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)dir_open_xpm);
+		directory_closed_pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)dir_close_xpm);
+		
+	}
+
 	standard_cursor=gdk_cursor_new(GDK_X_CURSOR);
 	busy_cursor=gdk_cursor_new(GDK_WATCH);
-	
+
 	return TRUE;
 }
 
@@ -104,13 +101,6 @@ void unload_graphics()
 {
 	if (program_icon_pixbuf!=NULL) g_object_unref(program_icon_pixbuf);
 
-	
-	if (cpp_file_pixbuf!=NULL) g_object_unref(cpp_file_pixbuf);
-	if (header_file_pixbuf!=NULL) g_object_unref(header_file_pixbuf);
-	if (txt_file_pixbuf!=NULL) g_object_unref(txt_file_pixbuf);
-	if (java_file_pixbuf!=NULL) g_object_unref(java_file_pixbuf);
-	if (lua_file_pixbuf!=NULL) g_object_unref(lua_file_pixbuf);
-
 	if (directory_closed_pixbuf!=NULL) g_object_unref(directory_closed_pixbuf);
 	if (directory_open_pixbuf!=NULL) g_object_unref(directory_open_pixbuf);
 }
